==> aws-cdk-lib-2.153.0-sources.jar: software/amazon/awscdk/services/rds/CaCertificate.java <==
package software.amazon.awscdk.services.rds;

/**
 * The CA certificate used for a DB instance.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Vpc vpc;
 * DatabaseCluster cluster = DatabaseCluster.Builder.create(this, "Database")
 *         .masterUser(Login.builder()
 *                 .username("myuser")
 *                 .build())
 *         .instanceType(InstanceType.of(InstanceClass.MEMORY5, InstanceSize.LARGE))
 *         .vpcSubnets(SubnetSelection.builder()
 *                 .subnetType(SubnetType.PUBLIC)
 *                 .build())
 *         .vpc(vpc)
 *         .caCertificate(CaCertificate.RDS_CA_RSA4096_G1)
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL.html">https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.101.0 (build b95fe5d)", date = "2024-08-19T23:46:39.403Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_rds.CaCertificate")
public class CaCertificate extends software.amazon.jsii.JsiiObject {

    protected CaCertificate(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CaCertificate(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        RDS_CA_2019 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_2019", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_ECC384_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_ECC384_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_RDS2048_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_RDS2048_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_RDS4096_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_RDS4096_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_RSA2048_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_RSA2048_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_RSA4096_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_RSA4096_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
    }

    /**
     * Custom CA certificate.
     * <p>
     * @param identifier <ul><li>CA certificate identifier.</li></ul> This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.CaCertificate of(final @org.jetbrains.annotations.NotNull java.lang.String identifier) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.CaCertificate.class, "of", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class), new Object[] { java.util.Objects.requireNonNull(identifier, "identifier is required") });
    }

    /**
     * Returns the CA certificate identifier as a string.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String toString() {
        return software.amazon.jsii.Kernel.call(this, "toString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * rds-ca-2019 certificate authority.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_2019;

    /**
     * rds-ca-ecc384-g1 certificate authority.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_ECC384_G1;

    /**
     * (deprecated) rds-ca-rsa2048-g1 certificate authority.
     * <p>
     * @deprecated use RDS_CA_RSA2048_G1 (slight misspelling)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_RDS2048_G1;

    /**
     * (deprecated) rds-ca-rsa4096-g1 certificate authority.
     * <p>
     * @deprecated use RDS_CA_RSA4096_G1 (slight misspelling)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_RDS4096_G1;

    /**
     * rds-ca-rsa2048-g1 certificate authority.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_RSA2048_G1;

    /**
     * rds-ca-rsa4096-g1 certificate authority.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_RSA4096_G1;
}

==> aws-cdk-lib-2.160.0-sources.jar: software/amazon/awscdk/services/rds/CaCertificate.java <==
package software.amazon.awscdk.services.rds;

/**
 * The CA certificate used for a DB instance.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Vpc vpc;
 * DatabaseCluster cluster = DatabaseCluster.Builder.create(this, "Database")
 *         .masterUser(Login.builder()
 *                 .username("myuser")
 *                 .build())
 *         .instanceType(InstanceType.of(InstanceClass.MEMORY5, InstanceSize.LARGE))
 *         .vpcSubnets(SubnetSelection.builder()
 *                 .subnetType(SubnetType.PUBLIC)
 *                 .build())
 *         .vpc(vpc)
 *         .caCertificate(CaCertificate.RDS_CA_RSA4096_G1)
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL.html">https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.103.1 (build bef2dea)", date = "2024-09-24T10:56:38.595Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_rds.CaCertificate")
public class CaCertificate extends software.amazon.jsii.JsiiObject {

    protected CaCertificate(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CaCertificate(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        RDS_CA_2019 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_2019", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_ECC384_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_ECC384_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_RDS2048_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_RDS2048_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_RDS4096_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_RDS4096_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_RSA2048_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_RSA2048_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
        RDS_CA_RSA4096_G1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.CaCertificate.class, "RDS_CA_RSA4096_G1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class));
    }

    /**
     * Custom CA certificate.
     * <p>
     * @param identifier <ul><li>CA certificate identifier.</li></ul> This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.CaCertificate of(final @org.jetbrains.annotations.NotNull java.lang.String identifier) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.CaCertificate.class, "of", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.CaCertificate.class), new Object[] { java.util.Objects.requireNonNull(identifier, "identifier is required") });
    }

    /**
     * Returns the CA certificate identifier as a string.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String toString() {
        return software.amazon.jsii.Kernel.call(this, "toString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (deprecated) rds-ca-2019 certificate authority.
     * <p>
     * @deprecated rds-ca-2019 expired in August, 2024.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_2019;

    /**
     * rds-ca-ecc384-g1 certificate authority.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_ECC384_G1;

    /**
     * (deprecated) rds-ca-rsa2048-g1 certificate authority.
     * <p>
     * @deprecated use RDS_CA_RSA2048_G1 (slight misspelling)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_RDS2048_G1;

    /**
     * (deprecated) rds-ca-rsa4096-g1 certificate authority.
     * <p>
     * @deprecated use RDS_CA_RSA4096_G1 (slight misspelling)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_RDS4096_G1;

    /**
     * rds-ca-rsa2048-g1 certificate authority.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_RSA2048_G1;

    /**
     * rds-ca-rsa4096-g1 certificate authority.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.CaCertificate RDS_CA_RSA4096_G1;
}
